@@ -15,9 +15,13 @@ class LiveMeter(LiveInstrument):
         self.hit_limit = -1
         self.type = LiveInstrumentType.METER
 
+    def to_dict(self):
+        dict = humps.camelize(json.loads(self.to_json()))
+        dict["meta"] = self.__dict__["meta"]
+        return dict
+
     @classmethod
-    def from_json(cls, json_str):
-        json_dict = humps.decamelize(json.loads(json_str))
+    def from_dict(cls, json_dict):
         # todo: easier way to convert
         location = LiveSourceLocation(json_dict["location"]["source"], json_dict["location"]["line"])
         meter = LiveMeter(location)
@@ -30,3 +34,8 @@ class LiveMeter(LiveInstrument):
 
         meter.type = LiveInstrumentType.METER
         return meter
+
+    @classmethod
+    def from_json(cls, json_str):
+        json_dict = humps.decamelize(json.loads(json_str))
+        return cls.from_dict(json_dict)
